.. include:: definitions.txt

.. _`why`:

Why (and why not) using ProcGraph
====================================

|towrite|

Related work
------------

* dataflow programming

* zflow 0.01: Flow-based Programming Library for Python

* http://en.wikipedia.org/wiki/Hartmann_pipeline

* http://code.google.com/p/python-pipelines/
